﻿namespace Zachowania
{
    internal class PrzyciskZLicznikiem : Behavior<Button>
    {
        public int Licznik { get; set; } = 0;

        protected override void OnAttachedTo(Button button)
        {
            base.OnAttachedTo(button);
            if(button != null)
            {
                button.Clicked += button_Clicked;
                button.Text = "Licznik: " + Licznik.ToString();
                button.BackgroundColor = Colors.Red;
            }
        }

        protected override void OnDetachingFrom(Button button)
        {
            base.OnDetachingFrom(button);
            button.Clicked -= button_Clicked;
        }

        private void button_Clicked(object? sender, EventArgs e)
        {
            Licznik++;
            Button? button = sender as Button;
            if (button != null)
            {
                button.Text = "Licznik: " + Licznik.ToString();
                button.BackgroundColor = Colors.Lime;
            }
        }
    }

    internal class PrzyciskZmieniającyTło : Behavior<VisualElement>
    {
        public VisualElement VisualElement { get; private set; } = null;

        protected override void OnAttachedTo(VisualElement visualElement)
        {
            base.OnAttachedTo(visualElement);
            this.VisualElement = visualElement;
        }

        //własność wiązania/wiązalną = własność zależności
        public static readonly BindableProperty PrzyciskProperty =
            BindableProperty.Create(
                nameof(Przycisk),
                typeof(Button),
                typeof(PrzyciskZmieniającyTło),
                null,
                BindingMode.OneWay,
                null,
                przyciskZmieniony);

        public Button Przycisk
        {
            get { return (Button)GetValue(PrzyciskProperty); }
            set { SetValue(PrzyciskProperty, value);}
        }

        public Color Kolor { get; set; } = Colors.Yellow;

        private static void przyciskZmieniony(BindableObject b, object oldValue, object newValue)
        {
            EventHandler button_Click =
                (object sender, EventArgs e) =>
                {
                    PrzyciskZmieniającyTło _b = b as PrzyciskZmieniającyTło;
                    if (_b.VisualElement != null)
                        _b.VisualElement.Background = _b.Kolor;
                };
            if(oldValue != null) (oldValue as Button).Clicked -= button_Click;
            if(newValue != null) (newValue as Button).Clicked += button_Click;
        }
    }
}
